@@ -35,6 +35,7 @@ def mms_part_slice2d(trange=None,
                      resolution=None,
                      interpolation='geometric',
                      contours=False,
+                     title=None,
                      smooth=None,
                      save_jpeg=None,
                      save_png=None,
@@ -266,4 +267,4 @@ def mms_part_slice2d(trange=None,
 
     plot(the_slice, xrange=xrange, yrange=yrange, zrange=zrange, save_png=save_png, save_svg=save_svg,
          save_pdf=save_pdf, save_eps=save_eps, save_jpeg=save_jpeg, display=display, dpi=dpi, plotsize=plotsize,
-         contours=contours, colormap=cmap)
+         contours=contours, colormap=cmap, title=title)
